@@ -41,6 +41,9 @@ describe 'neutron::agents::l3' do
       should contain_neutron_l3_agent_config('DEFAULT/radvd_user').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('agent/availability_zone').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('agent/extensions').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_l3_agent_config('network_log/rate_limit').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_l3_agent_config('network_log/burst_limit').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_l3_agent_config('network_log/local_output_log_base').with_value('<SERVICE DEFAULT>')
     end
 
     it 'passes purge to resource' do
@@ -120,6 +123,26 @@ describe 'neutron::agents::l3' do
         should contain_neutron_l3_agent_config('agent/availability_zone').with_value(p[:availability_zone])
       end
     end
+
+    context 'with extensions in string' do
+      before :each do
+        params.merge!(:extensions => 'fip_qos,gateway_ip_qos,port_forwarding')
+      end
+
+      it 'configures extentions' do
+        should contain_neutron_l3_agent_config('agent/extensions').with_value('fip_qos,gateway_ip_qos,port_forwarding')
+      end
+    end
+
+    context 'with extensions in array' do
+      before :each do
+        params.merge!(:extensions => ['fip_qos', 'gateway_ip_qos', 'port_forwarding'])
+      end
+
+      it 'configures extentions' do
+        should contain_neutron_l3_agent_config('agent/extensions').with_value('fip_qos,gateway_ip_qos,port_forwarding')
+      end
+    end
   end
 
   shared_examples 'neutron::agents::l3 on Debian' do
